@@ -25,6 +25,7 @@
 #include <string.h>
 #include <math.h>
 #include <locale.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include <libxml/xmlreader.h>
 
@@ -77,7 +78,7 @@
  * and possibly several, weather stations inside it. Weather stations
  * will never appear outside of cities.
  *
- * Building a database with gweather_location_new_world() will never
+ * Building a database with gweather_location_get_world() will never
  * create detached instances, but deserializing might.
  **/
 
@@ -138,6 +139,7 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
     loc->parent = parent;
     loc->level = level;
     loc->ref_count = 1;
+    loc->msgctxt = NULL;
     if (level == GWEATHER_LOCATION_WORLD)
 	loc->metar_code_cache = g_hash_table_ref (parser->metar_code_cache);
     children = g_ptr_array_new ();
@@ -154,54 +156,53 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 
 	tagname = (const char *) xmlTextReaderConstName (parser->xml);
 	if (!strcmp (tagname, "name") && !loc->name) {
-	    value = gweather_parser_get_localized_value (parser);
+            loc->msgctxt = _gweather_parser_get_msgctxt_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
-	    loc->name = g_strdup (value);
-	    xmlFree (value);
+	    loc->name = value;
 	    normalized = g_utf8_normalize (loc->name, -1, G_NORMALIZE_ALL);
 	    loc->sort_name = g_utf8_casefold (normalized, -1);
 	    g_free (normalized);
-
 	} else if (!strcmp (tagname, "iso-code") && !loc->country_code) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->country_code = g_strdup (value);
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "tz-hint") && !loc->tz_hint) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->tz_hint = g_strdup (value);
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "code") && !loc->station_code) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->station_code = g_strdup (value);
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "coordinates") && !loc->latlon_valid) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    if (parse_coordinates (value, &loc->latitude, &loc->longitude))
 		loc->latlon_valid = TRUE;
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "zone") && !loc->forecast_zone) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->forecast_zone = g_strdup (value);
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "yahoo-woeid") && !loc->yahoo_id) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->yahoo_id = g_strdup (value);
 	    xmlFree (value);
 	} else if (!strcmp (tagname, "radar") && !loc->radar) {
-	    value = gweather_parser_get_value (parser);
+	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 	    loc->radar = g_strdup (value);
@@ -211,19 +212,7 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 	    child = location_new_from_xml (parser, GWEATHER_LOCATION_REGION, loc);
 	    if (!child)
 		goto error_out;
-	    if (parser->use_regions)
-		g_ptr_array_add (children, child);
-	    else {
-		if (child->children) {
-		    for (i = 0; child->children[i]; i++) {
-			/* Correct back pointers */
-			child->children[i]->parent = loc;
-			g_ptr_array_add (children, child->children[i]);
-		    }
-		}
-		child->children = NULL;
-		gweather_location_unref (child);
-	    }
+	    g_ptr_array_add (children, child);
 	} else if (!strcmp (tagname, "country")) {
 	    child = location_new_from_xml (parser, GWEATHER_LOCATION_COUNTRY, loc);
 	    if (!child)
@@ -251,7 +240,7 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 	    g_ptr_array_add (children, child);
 
 	} else if (!strcmp (tagname, "timezones")) {
-	    loc->zones = gweather_timezones_parse_xml (parser);
+	    loc->zones = _gweather_timezones_parse_xml (parser);
 	    if (!loc->zones)
 		goto error_out;
 
@@ -298,45 +287,40 @@ error_out:
 static GWeatherLocation *global_world;
 
 /**
- * gweather_location_new_world:
- * @use_regions: whether or not to divide the world into regions (deprecated)
+ * gweather_location_get_world:
  *
- * Creates a new #GWeatherLocation of type %GWEATHER_LOCATION_WORLD,
+ * Obtains the shared #GWeatherLocation of type %GWEATHER_LOCATION_WORLD,
  * representing a hierarchy containing all of the locations from
  * Locations.xml.
  *
- * Starting from 3.10, multiple invocations to this function return the
- * same location.
- *
- * In the past, the @use_regions parameter could be used to control
- * if the immediate children were %GWEATHER_LOCATION_REGION or
- * %GWEATHER_LOCATION_COUNTRY nodes. Now it is deprecated and treated
- * always as %TRUE. A diagnostic message is printed if %FALSE is passed.
- *
- * Return value: (allow-none) (transfer full): a %GWEATHER_LOCATION_WORLD
+ * Return value: (allow-none) (transfer none): a %GWEATHER_LOCATION_WORLD
  * location, or %NULL if Locations.xml could not be found or could not be parsed.
+ * The return value is owned by libgweather and should not be modified or freed.
  **/
 GWeatherLocation *
-gweather_location_new_world (gboolean use_regions)
+gweather_location_get_world (void)
 {
     GWeatherParser *parser;
 
-    if (!use_regions)
-	g_message ("passing FALSE to gweather_location_new_world() is deprecated, ignoring");
+    if (!global_world) {
+	parser = _gweather_parser_new ();
+	if (!parser)
+	    return NULL;
 
-    if (global_world)
-	return gweather_location_ref (global_world);
+	global_world = location_new_from_xml (parser, GWEATHER_LOCATION_WORLD, NULL);
+	_gweather_parser_free (parser);
+    }
 
-    parser = gweather_parser_new (TRUE);
-    if (!parser)
-	return NULL;
-
-    global_world = location_new_from_xml (parser, GWEATHER_LOCATION_WORLD, NULL);
-
-    gweather_parser_free (parser);
     return global_world;
 }
 
+/* deprecated */
+GWeatherLocation *
+gweather_location_new_world (gboolean use_regions)
+{
+    return gweather_location_ref (gweather_location_get_world ());
+}
+
 /**
  * gweather_location_ref:
  * @loc: a #GWeatherLocation
@@ -371,7 +355,10 @@ gweather_location_unref (GWeatherLocation *loc)
     if (--loc->ref_count)
 	return;
 
+    g_return_if_fail (loc->level != GWEATHER_LOCATION_WORLD);
+
     g_free (loc->name);
+    g_free (loc->msgctxt);
     g_free (loc->sort_name);
     g_free (loc->country_code);
     g_free (loc->tz_hint);
@@ -396,9 +383,6 @@ gweather_location_unref (GWeatherLocation *loc)
     if (loc->metar_code_cache)
 	g_hash_table_unref (loc->metar_code_cache);
 
-    if (loc->level == GWEATHER_LOCATION_WORLD)
-	global_world = NULL;
-
     g_slice_free (GWeatherLocation, loc);
 }
 
@@ -434,7 +418,17 @@ const char *
 gweather_location_get_name (GWeatherLocation *loc)
 {
     g_return_val_if_fail (loc != NULL, NULL);
-    return loc->name;
+
+    const char *ret;
+
+    if (loc->msgctxt) {
+	ret = (const char*) g_dpgettext2 ("libgweather-locations",
+				       (char*) loc->msgctxt, (char*) loc->name);
+    } else {
+	ret = (const char*) g_dgettext ("libgweather-locations", (char*) loc->name);
+    }
+
+    return g_strdup (ret);
 }
 
 /**
@@ -510,23 +504,6 @@ gweather_location_get_children (GWeatherLocation *loc)
 	return &no_children;
 }
 
-
-/**
- * gweather_location_free_children:
- * @loc: a #GWeatherLocation
- * @children: an array of @loc's children
- *
- * This is a no-op. Do not use it.
- *
- * Deprecated: This is a no-op.
- **/
-void
-gweather_location_free_children (GWeatherLocation  *loc,
-				 GWeatherLocation **children)
-{
-    ;
-}
-
 /**
  * gweather_location_has_coords:
  * @loc: a #GWeatherLocation
@@ -744,15 +721,28 @@ gweather_location_get_city_name (GWeatherLocation *loc)
 {
     g_return_val_if_fail (loc != NULL, NULL);
 
+    const char *ret;
+
     if (loc->level == GWEATHER_LOCATION_CITY ||
-	loc->level == GWEATHER_LOCATION_DETACHED)
-	return g_strdup (loc->name);
-    else if (loc->level == GWEATHER_LOCATION_WEATHER_STATION &&
-	     loc->parent &&
-	     loc->parent->level == GWEATHER_LOCATION_CITY)
-	return g_strdup (loc->parent->name);
-    else
-	return NULL;
+        loc->level == GWEATHER_LOCATION_DETACHED) {
+        if (loc->msgctxt) {
+            ret = (const char*) g_dpgettext2 ("libgweather-locations", (char*) loc->msgctxt, (char*) loc->name);
+        } else {
+            ret = (const char*) g_dgettext ("libgweather-locations", (char*) loc->name);
+        }
+
+        return g_strdup (ret);
+    } else if (loc->level == GWEATHER_LOCATION_WEATHER_STATION &&
+               loc->parent &&
+               loc->parent->level == GWEATHER_LOCATION_CITY) {
+        if (loc->parent->msgctxt) {
+            ret = (const char*) g_dpgettext2 ("libgweather-locations", (char*) loc->parent->msgctxt, (char*) loc->parent->name);
+        } else {
+            ret = (const char*) g_dgettext ("libgweather-locations", (char*) loc->parent->name);
+        }
+        return g_strdup (ret);
+    } else
+        return NULL;
 }
 
 void
@@ -828,18 +818,6 @@ gweather_location_find_by_station_code (GWeatherLocation *world,
     return l ? l->data : NULL;
 }
 
-GWeatherLocation *
-gweather_location_ref_world (GWeatherLocation *loc)
-{
-    while (loc &&
-	   loc->level != GWEATHER_LOCATION_WORLD)
-	loc = loc->parent;
-
-    if (loc)
-	gweather_location_ref (loc);
-    return loc;
-}
-
 /**
  * gweather_location_equal:
  * @one: a #GWeatherLocation
@@ -941,6 +919,7 @@ _gweather_location_new_detached (GWeatherLocation *nearest_station,
     char *normalized;
 
     self = g_slice_new0 (GWeatherLocation);
+    self->ref_count = 1;
     self->level = GWEATHER_LOCATION_DETACHED;
     self->name = g_strdup (name);
 
@@ -1033,7 +1012,7 @@ gweather_location_format_one_deserialize (GWeatherLocation *world,
 	    if (g_strcmp0 (name, city->name) == 0)
 		found = gweather_location_ref (city);
 	    else
-		found = _gweather_location_new_detached (city, name, FALSE, 0, 0);
+		found = _gweather_location_new_detached (ws, name, TRUE, latitude, longitude);
 
 	    break;
 	}
